8170632: Stop modifying VERSION_OPT for adhoc builds on reconfigure
authorihse
Wed, 07 Dec 2016 09:46:39 +0100
changeset 42423 bc717b8b1123
parent 42422 5455cb741977
child 42424 2ac2a6ef14a6
8170632: Stop modifying VERSION_OPT for adhoc builds on reconfigure Reviewed-by: erikj
common/autoconf/generated-configure.sh
common/autoconf/jdk-version.m4
--- a/common/autoconf/jdk-version.m4	Wed Dec 07 09:23:37 2016 +0100
+++ b/common/autoconf/jdk-version.m4	Wed Dec 07 09:46:39 2016 +0100
@@ -160,11 +160,10 @@
     fi
   else
     if test "x$NO_DEFAULT_VERSION_PARTS" != xtrue; then
-      # Default is to calculate a string like this <timestamp>.<username>.<base dir name>
-      timestamp=`$DATE '+%Y-%m-%d-%H%M%S'`
+      # Default is to calculate a string like this 'adhoc.<username>.<base dir name>'
       # Outer [ ] to quote m4.
       [ basedirname=`$BASENAME "$TOPDIR" | $TR -d -c '[a-z][A-Z][0-9].-'` ]
-      VERSION_OPT="$timestamp.$USERNAME.$basedirname"
+      VERSION_OPT="adhoc.$USERNAME.$basedirname"
     fi
   fi
--- a/common/autoconf/generated-configure.sh	Wed Dec 07 09:23:37 2016 +0100
+++ b/common/autoconf/generated-configure.sh	Wed Dec 07 09:46:39 2016 +0100
@@ -5082,7 +5082,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1481098917
+DATE_WHEN_GENERATED=1481100369
 
 ###############################################################################
 #
@@ -24451,11 +24451,10 @@
     fi
   else
     if test "x$NO_DEFAULT_VERSION_PARTS" != xtrue; then
-      # Default is to calculate a string like this <timestamp>.<username>.<base dir name>
-      timestamp=`$DATE '+%Y-%m-%d-%H%M%S'`
+      # Default is to calculate a string like this 'adhoc.<username>.<base dir name>'
       # Outer [ ] to quote m4.
        basedirname=`$BASENAME "$TOPDIR" | $TR -d -c '[a-z][A-Z][0-9].-'`
-      VERSION_OPT="$timestamp.$USERNAME.$basedirname"
+      VERSION_OPT="adhoc.$USERNAME.$basedirname"
     fi
   fi
 